@@ -41,8 +41,6 @@
 
 #define KNEWSTUFFCORE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KNEWSTUFFCORE_NO_DEPRECATED) && !defined(KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KNEWSTUFFCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNEWSTUFFCORE_NO_DEPRECATED
-#  define KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef KNEWSTUFFCORE_NO_DEPRECATED_WARNINGS
 #  define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KNEWSTUFFCORE_DEPRECATED
-#  define KNEWSTUFFCORE_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KNEWSTUFFCORE_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KNEWSTUFFCORE_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
